<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/plan?lang_cible=pt_br
// ** ne pas modifier le fichier **

return [

	// C
	'confirmer_deplacement' => 'Você quer realmente deslocar estes elementos?',

	// D
	'deplacement_en_echec' => 'Falha de uma deslocação.',
	'deplacement_identifiant_absent' => 'Nenhum',
	'deplacement_reussi' => 'Deslocação efetuada.',
	'deplacements_en_echec' => '@nb@ deslocações falharam.',
	'deplacements_reussis' => '@nb@ deslocações efetuadas.',

	// E
	'erreur_aucun_identifiant' => 'Nenhum identificador de objeto.',
	'erreur_autorisation_insuffisante' => 'Autorização insuficiente.',
	'erreur_deplacement' => 'Deslocação não efetuada.',
	'erreur_deplacement_impossible' => 'Deslocação impossível!',
	'erreur_rubriques_parentes_incorrectes' => 'Seções superiores incorretas.',

	// P
	'plan_titre' => 'Mapa do site na área privada',

	// S
	'suggerer_deplier' => 'Isso poder ocorrer devido à deslocação de um grande grupo: neste caso a lista dos seus subordinados não é carregada. Você deve expandir o bloco (ele se carregará), retraí-lo de novo e, então, deslocá-lo.',

	// T
	'tous_les_statuts' => 'Todos os statuts',
];
